Page 173 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 173

Home

    Insiders began to roll off the press in books and articles,
    some being sold in the millions. Audio tapes and videos
    were produced and distributed across the country.
    Bookstores were opened and a national speakers bureau
    was established. From the standpoint of the Insiders,

    something had to be done.
    Since the Insiders could not refute the truth being told

    about them, they launched the most massive smear
    campaign that had ever been experienced by any private
    group in the United States. The CFR-controlled news
    media spearheaded the attack, spreading misinformation,
    and outright lies about the JBS on a daily basis. The
    attacks slowed down but never stopped the Society.
    Years later at the 35th anniversary celebration of the JBS

    in Indianapolis, Indiana, long time staff member Thomas
    Hill gave this account of the efforts to destroy the JBS:

    Thirty-five years ago in this city called Indianapolis,
    eleven men gathered to hear what another man was
    prepared to tell them. Thirty-two years ago, most of the
    National and International Press, political leaders in the
    federal government as well as political leaders in many
    state governments, liberal and pro-communist pundits
    from one coast to another, and a host of hacks and

    assorted opportunists of every conceivable description,
    assured their readers, and all who would listen, that this
    scourge of the country, this semi-secret, fanatical and
    undemocratic monstrosity known as The John Birch
    Society, would soon be relegated into obscurity.

    In 1968, some seven years later, The John Birch
    Society celebrated the 10th anniversary of its founding.

    168

    The Secret Side of History